==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/FieldOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FieldOptionsFluentImpl<A extends FieldOptionsFluent<A>> extends BaseFluent<A> implements FieldOptionsFluent<A>{
  public FieldOptionsFluentImpl() {
  }
  public FieldOptionsFluentImpl(FieldOptions instance) {
    this.withCreate(instance.getCreate()); 
    this.withDelimiter(instance.getDelimiter()); 
    this.withEncoding(instance.getEncoding()); 
    this.withIndex(instance.getIndex()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Boolean create;
  private String delimiter;
  private String encoding;
  private Integer index;
  private Map<String,Object> additionalProperties;
  public Boolean getCreate() {
    return this.create;
  }
  public A withCreate(Boolean create) {
    this.create=create; return (A) this;
  }
  public Boolean hasCreate() {
    return this.create != null;
  }
  public String getDelimiter() {
    return this.delimiter;
  }
  public A withDelimiter(String delimiter) {
    this.delimiter=delimiter; return (A) this;
  }
  public Boolean hasDelimiter() {
    return this.delimiter != null;
  }
  public String getEncoding() {
    return this.encoding;
  }
  public A withEncoding(String encoding) {
    this.encoding=encoding; return (A) this;
  }
  public Boolean hasEncoding() {
    return this.encoding != null;
  }
  public Integer getIndex() {
    return this.index;
  }
  public A withIndex(Integer index) {
    this.index=index; return (A) this;
  }
  public Boolean hasIndex() {
    return this.index != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FieldOptionsFluentImpl that = (FieldOptionsFluentImpl) o;
    if (create != null ? !create.equals(that.create) :that.create != null) return false;
    if (delimiter != null ? !delimiter.equals(that.delimiter) :that.delimiter != null) return false;
    if (encoding != null ? !encoding.equals(that.encoding) :that.encoding != null) return false;
    if (index != null ? !index.equals(that.index) :that.index != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(create,  delimiter,  encoding,  index,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (create != null) { sb.append("create:"); sb.append(create + ","); }
    if (delimiter != null) { sb.append("delimiter:"); sb.append(delimiter + ","); }
    if (encoding != null) { sb.append("encoding:"); sb.append(encoding + ","); }
    if (index != null) { sb.append("index:"); sb.append(index + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withCreate() {
    return withCreate(true);
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/FieldOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FieldOptionsFluentImpl<A extends FieldOptionsFluent<A>> extends BaseFluent<A> implements FieldOptionsFluent<A>{
  public FieldOptionsFluentImpl() {
  }
  public FieldOptionsFluentImpl(FieldOptions instance) {
    if (instance != null) {
      this.withCreate(instance.getCreate());
      this.withDelimiter(instance.getDelimiter());
      this.withEncoding(instance.getEncoding());
      this.withIndex(instance.getIndex());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean create;
  private String delimiter;
  private String encoding;
  private Integer index;
  private Map<String,Object> additionalProperties;
  public Boolean getCreate() {
    return this.create;
  }
  public A withCreate(Boolean create) {
    this.create=create; return (A) this;
  }
  public Boolean hasCreate() {
    return this.create != null;
  }
  public String getDelimiter() {
    return this.delimiter;
  }
  public A withDelimiter(String delimiter) {
    this.delimiter=delimiter; return (A) this;
  }
  public Boolean hasDelimiter() {
    return this.delimiter != null;
  }
  public String getEncoding() {
    return this.encoding;
  }
  public A withEncoding(String encoding) {
    this.encoding=encoding; return (A) this;
  }
  public Boolean hasEncoding() {
    return this.encoding != null;
  }
  public Integer getIndex() {
    return this.index;
  }
  public A withIndex(Integer index) {
    this.index=index; return (A) this;
  }
  public Boolean hasIndex() {
    return this.index != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FieldOptionsFluentImpl that = (FieldOptionsFluentImpl) o;
    if (!java.util.Objects.equals(create, that.create)) return false;

    if (!java.util.Objects.equals(delimiter, that.delimiter)) return false;

    if (!java.util.Objects.equals(encoding, that.encoding)) return false;

    if (!java.util.Objects.equals(index, that.index)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(create,  delimiter,  encoding,  index,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (create != null) { sb.append("create:"); sb.append(create + ","); }
    if (delimiter != null) { sb.append("delimiter:"); sb.append(delimiter + ","); }
    if (encoding != null) { sb.append("encoding:"); sb.append(encoding + ","); }
    if (index != null) { sb.append("index:"); sb.append(index + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withCreate() {
    return withCreate(true);
  }
  
}
